summaryrefslogtreecommitdiff
path: root/yarnlib/mdparser.py
diff options
context:
space:
mode:
authorLars Wirzenius <liw@liw.fi>2013-06-19 20:42:58 +0100
committerLars Wirzenius <liw@liw.fi>2013-06-19 20:42:58 +0100
commit2c288169fd38032575feb4414c039e9c1e9e8764 (patch)
tree365b3467e08cac322943ce00830dfb140fcfb77a /yarnlib/mdparser.py
parent54e347e461327c09746b45d19b1d24631652da8e (diff)
downloadcmdtest-2c288169fd38032575feb4414c039e9c1e9e8764.tar.gz
Switch to "scenario testing"
Diffstat (limited to 'yarnlib/mdparser.py')
-rw-r--r--yarnlib/mdparser.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/yarnlib/mdparser.py b/yarnlib/mdparser.py
index 6d16772..6708369 100644
--- a/yarnlib/mdparser.py
+++ b/yarnlib/mdparser.py
@@ -25,7 +25,7 @@ from markdown.treeprocessors import Treeprocessor
#
# Classes for Markdown parsing. See python-markdown documentation
# for details. We want to find all top level code blocks (indented
# four spaces in the Markdown), which we'll parse for story test
# stuff later on. We create a Python markdown extension and use
# "tree processor" to analyse the parsed ElementTree at the right
# moment for top level <pre> blocks.
@@ -50,7 +50,7 @@ class GatherCodeBlocks(Treeprocessor):
# gatherer at the right time. It stores the list of top level
# code blocks as the blocks attribute.
-class ParseStoryTestBlocks(markdown.extensions.Extension):
+class ParseScenarioTestBlocks(markdown.extensions.Extension):
def extendMarkdown(self, md, md_globals):
self.blocks = []
@@ -64,7 +64,7 @@ class MarkdownParser(object):
self.blocks = []
def parse_string(self, text):
- ext = ParseStoryTestBlocks()
+ ext = ParseScenarioTestBlocks()
f = StringIO.StringIO()
markdown.markdown(text, output=f, extensions=[ext])
self.blocks = ext.blocks
@@ -25,7 +25,7 @@ from markdown.treeprocessors import Treeprocessor
# Classes for Markdown parsing. See python-markdown documentation
# for details. We want to find all top level code blocks (indented
-# four spaces in the Markdown), which we'll parse for story test
+# four spaces in the Markdown), which we'll parse for scenario test
# stuff later on. We create a Python markdown extension and use
# "tree processor" to analyse the parsed ElementTree at the right